==> v_chat_sdk_core-0.0.3.tar.gz: lib/src/models/v_room/group/room_data_member_model.dart <==
import '../../../../v_chat_sdk_core.dart';

class VRoomDataMemberModel {
  final RoomType roomType;
  String? transTo;
  String title;
  String? nTitle;
  String img;
  bool isMuted;
  bool isDeleted;
  bool isArchive;
  String createdAt;

//<editor-fold desc="Data Methods">

  VRoomDataMemberModel({
    required this.roomType,
    this.transTo,
    required this.title,
    required this.createdAt,
    this.nTitle,
    required this.img,
    required this.isMuted,
    required this.isDeleted,
    required this.isArchive,
  });

  @override
  String toString() {
    return 'RoomDataMemberModel{ roomType: $roomType, transTo: $transTo, title: $title, nTitle: $nTitle, img: $img, isMuted: $isMuted, isDeleted: $isDeleted, isArchive: $isArchive,}';
  }

  Map<String, dynamic> toMap() {
    return {
      'rT': roomType.name,
      'tTo': transTo,
      't': title,
      'nTitle': nTitle,
      'img': img,
      'isM': isMuted,
      'isD': isDeleted,
      'isA': isArchive,
      'createdAt': createdAt,
    };
  }

  factory VRoomDataMemberModel.fromMap(Map<String, dynamic> map) {
    return VRoomDataMemberModel(
      roomType: RoomType.values.byName(map['rT'] as String),
      transTo: map['tTo'] as String?,
      title: map['t'] as String,
      nTitle: map['nTitle'] as String?,
      img: map['img'] as String,
      isMuted: map['isM'] as bool,
      isDeleted: map['isD'] as bool,
      isArchive: map['isA'] as bool,
      createdAt: map['createdAt'] as String,
    );
  }

//</editor-fold>
}

==> v_chat_sdk_core-0.2.0.tar.gz: lib/src/models/v_room/group/room_data_member_model.dart <==
import 'package:v_chat_sdk_core/v_chat_sdk_core.dart';

class VRoomDataMemberModel {
  final VRoomType roomType;
  String? transTo;
  String title;
  String? nTitle;
  String img;
  bool isMuted;
  bool isDeleted;
  bool isArchive;
  String createdAt;

//<editor-fold desc="Data Methods">

  VRoomDataMemberModel({
    required this.roomType,
    this.transTo,
    required this.title,
    required this.createdAt,
    this.nTitle,
    required this.img,
    required this.isMuted,
    required this.isDeleted,
    required this.isArchive,
  });

  @override
  String toString() {
    return 'RoomDataMemberModel{ roomType: $roomType, transTo: $transTo, title: $title, nTitle: $nTitle, img: $img, isMuted: $isMuted, isDeleted: $isDeleted, isArchive: $isArchive,}';
  }

  Map<String, dynamic> toMap() {
    return {
      'rT': roomType.name,
      'tTo': transTo,
      't': title,
      'nTitle': nTitle,
      'img': img,
      'isM': isMuted,
      'isD': isDeleted,
      'isA': isArchive,
      'createdAt': createdAt,
    };
  }

  factory VRoomDataMemberModel.fromMap(Map<String, dynamic> map) {
    return VRoomDataMemberModel(
      roomType: VRoomType.values.byName(map['rT'] as String),
      transTo: map['tTo'] as String?,
      title: map['t'] as String,
      nTitle: map['nTitle'] as String?,
      img: map['img'] as String,
      isMuted: map['isM'] as bool,
      isDeleted: map['isD'] as bool,
      isArchive: map['isA'] as bool,
      createdAt: map['createdAt'] as String,
    );
  }

//</editor-fold>
}
